==> nextcloud-12.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/de_DE.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "Das Passwort muss mindestens %s Zeichen lang sein ",
    "Password needs to contain at least one lower and one upper case character." : "Das Passwort muss mindestens einen Klein- und einen Großbuchstaben beinhalten. ",
    "Password needs to contain at least one numeric character." : "Das Passwort muss mindestens eine Zahl beinhalten. ",
    "Password needs to contain at least one special character." : "Das Passwort muss mindestens ein Sonderzeichen enthalten. ",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Das Passwort ist unter den 1.000.000 häufigsten Passwörtern. Bitte wählen Sie ein anderes.",
    "Password policy" : "Passwort-Regeln",
    "Minimal length" : "Minimale Länge",
    "Forbid common passwords" : "Häufig verwendete Passwörter verbieten",
    "Enforce upper and lower case characters" : "Groß- und Kleinbuchstaben erzwingen",
    "Enforce numeric characters" : "Zahlen erzwingen",
    "Enforce special characters" : "Sonderzeichen erzwingen",
    "Password need to be at least %s characters long" : "Das Passwort muss mindestens %s Zeichen lang sein",
    "Password need to contain at least one lower case character and one upper case character." : "Das Passwort muss mindestens einen Klein- und einen Großbuchstaben beinhalten.",
    "Password need to contain at least one numeric character." : "Das Passwort muss mindestens eine Zahl beinhalten.",
    "Password need to contain at least one special character." : "Das Passwort muss mindestens ein Sonderzeichen enthalten.",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "Das Passwort zählt zu den 1.000.000 am häufigsten verwendeten Passwörtern. Bitte wählen Sie ein anderes Passwort."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/de_DE.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "Das Passwort muss mindestens %s Zeichen lang sein ",
    "Password needs to contain at least one lower and one upper case character." : "Das Passwort muss mindestens einen Klein- und einen Großbuchstaben beinhalten.",
    "Password needs to contain at least one numeric character." : "Das Passwort muss mindestens eine Zahl beinhalten. ",
    "Password needs to contain at least one special character." : "Das Passwort muss mindestens ein Sonderzeichen beinhalten. ",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Das Passwort ist unter den 1.000.000 häufigsten Passwörtern. Bitte wählen Sie ein anderes.",
    "Password policy" : "Passwort-Regeln",
    "Minimal length" : "Minimale Länge",
    "Forbid common passwords" : "Häufig verwendete Passwörter verbieten",
    "Enforce upper and lower case characters" : "Groß- und Kleinbuchstaben erzwingen",
    "Enforce numeric characters" : "Zahlen erzwingen",
    "Enforce special characters" : "Sonderzeichen erzwingen",
    "Password need to be at least %s characters long" : "Das Passwort muss mindestens %s Zeichen lang sein",
    "Password need to contain at least one lower case character and one upper case character." : "Das Passwort muss mindestens einen Klein- und einen Großbuchstaben beinhalten.",
    "Password need to contain at least one numeric character." : "Das Passwort muss mindestens eine Zahl beinhalten.",
    "Password need to contain at least one special character." : "Das Passwort muss mindestens ein Sonderzeichen beinhalten.",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "Das Passwort zählt zu den 1.000.000 am häufigsten verwendeten Passwörtern. Bitte wählen Sie ein anderes Passwort."
},
"nplurals=2; plural=(n != 1);");
